{ pkgs, ... }:

{
  imports = [
    # Modules
    ../../modules/home/default.nix
  ];

  config = {
    home = {
      username = "xeovalyte";
      homeDirectory = "/home/xeovalyte";
    };

    settings = {
      applications.common.enable = true;
      applications.alacritty.enable = true;
      applications.devenv.enable = true;
      applications.firefox.enable = true;
      applications.git.enable = true;
      applications.helix.enable = true;
      applications.zsh.enable = true;
      applications.ssh.enable = true;
      applications.thunderbird.enable = true;
      applications.yazi.enable = true;
      applications.zellij.enable = true;

      services.nextcloud-sync.enable = true;

      theming.fonts.enable = true;
      theming.stylix.enable = true;
      theming.stylix.wallpaper = "wallpaper-2.png";
      theming.stylix.theme = "da-one-ocean";

      desktop-environments.hyprland.enable = false;
    };

    home.packages = with pkgs; [
      # Desktop Applications
      kdenlive
      prismlauncher
      unstable.prusa-slicer
      signal-desktop
      unstable.vesktop
      blender
      unstable.freecad-wayland
      loupe
      unstable.rnote
      unstable.bottles
      unstable.hoppscotch

      # Office
      libreoffice

      # Image editing
      gimp
      inkscape
      unstable.obs-studio

      # Development
      unstable.drawio

      unstable.moonlight-qt

      # Scripts
      (import ../../modules/scripts/save_image.nix { inherit pkgs; })
    ];


    # Enable home-manager
    programs.home-manager.enable = true;

    home.stateVersion = "24.05";
  };
}
