{ lib, pkgs, ... }:

{
  imports = [
    # Import hardware configuration
    ./hardware-configuration.nix

    # Import modules
    ../../modules/system/default.nix
  ];

  settings = {
    display-manager = "gdm";
    desktop-environments = {
      cosmic.enable = false;
      hyprland.enable = false;
      gnome.enable = true;
    };
    applications = {
      common.enable = true;
      steam.enable = false;
      thunar.enable = false;
    };
    services = {
      docker.enable = false;
      quickemu.enable = false;
      sunshine.enable = false;
      garbage-collection.enable = true;
    };
    hardware = {
      fprint.enable = false;
      printing.enable = false;
      bluetooth.enable = true;
      firewall.enable = true;
      locale.enable = true;
      nvidia.enable = false;
    };
  };

  nix.settings = {
    experimental-features = [ "nix-command" "flakes" ];

    substituters = [
      "https://nix-community.cachix.org"
      "https://cosmic.cachix.org/"
    ];

    trusted-public-keys = [
      "cosmic.cachix.org-1:Dya9IyXD4xdBehWjrkPv6rtxpmMdRel02smYzA85dPE="
    ];
  };

  # Bootloader.
  boot.loader.efi.canTouchEfiVariables = true;
  boot.loader.grub = {
    enable = true;
    efiSupport = true;
    device = "nodev";
    configurationLimit = 32;
  };

  networking.hostName = "ti-clt-tbl01"; # Define your hostname.

  users.users.xeovalyte = {
    isNormalUser = true;
    description = "Timo Boomers";
    extraGroups = [ "networkmanager" "wheel" "dialout" ];
  };

  nix.settings.trusted-users = [ "root" "xeovalyte" ];

  # Prevent system freeze on high load
  services.earlyoom = {
    enable = true;
  };

  boot.kernelPackages = lib.mkForce pkgs.linuxPackages_latest;

  system.stateVersion = "24.05";

}
